<?php
// Configurações de logs de erro
ini_set('display_errors', 1);
ini_set('log_errors', 1);
ini_set('error_log', dirname(__FILE__) . '/error_log.txt');

// Depuração - Log de todas as requisições recebidas
error_log("Método HTTP: " . $_SERVER['REQUEST_METHOD']);
error_log("URL da requisição: " . $_SERVER['REQUEST_URI']);
error_log("Headers recebidos: " . print_r(getallheaders(), true));
error_log("Dados brutos recebidos: " . file_get_contents("php://input"));

// Definir cabeçalhos CORS para permitir requisições de qualquer origem
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: POST, GET, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');
header('Content-Type: application/json');

// Se for uma requisição OPTIONS, apenas retornar os cabeçalhos CORS
if ($_SERVER['REQUEST_METHOD'] == 'OPTIONS') {
    exit(0);
}

// Verifica se os dados foram enviados via POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Captura os dados do corpo da requisição (JSON)
    $input = file_get_contents("php://input");
    $data = json_decode($input, true);

    // Log dos dados recebidos
    error_log("Dados recebidos: " . print_r($data, true));

    // Validação mais rigorosa dos dados de entrada
    if (empty($data['nome']) || !is_string($data['nome']) || trim($data['nome']) === '') {
        echo json_encode([
            "success" => false,
            "message" => "Nome do cliente é inválido ou está em branco."
        ]);
        exit;
    }

    // Garantir que o nome é uma string válida e não apenas números
    $nome = trim($data['nome']);
    error_log("Nome recebido para pagamento: " . $nome);

    if (!preg_match('/[a-zA-Z]/', $nome)) {
        error_log("ALERTA: Nome contém apenas números ou caracteres não alfabéticos: " . $nome);
        // Não vamos bloquear, apenas registrar o alerta
    }

    if (empty($data['cpf'])) {
        echo json_encode([
            "success" => false,
            "message" => "CPF é obrigatório."
        ]);
        exit;
    }

    if (!preg_match('/^\d{11}$/', $data['cpf'])) {
        echo json_encode([
            "success" => false,
            "message" => "CPF inválido. Deve conter 11 dígitos."
        ]);
        exit;
    }

    // Valor fixo em centavos (R$ 59,90)
    $valorFixo = 5852;

    // Limpar o CPF (remover pontos e traços)
    $cpf = preg_replace('/[^0-9]/', '', $data['cpf']);

    // Preparar o nome adequadamente (não deve ser um número ou string vazia)
    $nome = trim($data['nome']);
    if (is_numeric($nome) || empty($nome)) {
        // Se for apenas números ou vazio, tenta recuperar dos parâmetros da URL
        if (isset($_GET['nome'])) {
            $nomeURL = urldecode($_GET['nome']);
            if (!empty($nomeURL) && !is_numeric($nomeURL)) {
                $nome = $nomeURL;
                error_log("Nome recuperado da URL: " . $nome);
            } else {
                $nome = "Cliente"; // Nome padrão como fallback
                error_log("Usando nome padrão 'Cliente' pois o valor recebido é inválido");
            }
        } else {
            $nome = "Cliente"; // Nome padrão como fallback
            error_log("Usando nome padrão 'Cliente' pois o valor recebido é inválido");
        }
    }

    // Dados do pagamento PIX
    $pixData = [
        "name" => $nome, // Nome do cliente validado
        "email" => "cliente@exemplo.com", // E-mail padrão
        "cpf" => $cpf, // CPF do cliente (limpo)
        "phone" => "16900000000", // Telefone padrão
        "paymentMethod" => "PIX", // Método de pagamento
        "amount" => $valorFixo, // Valor fixo em centavos
        "traceable" => true, // Rastreável
        "items" => [
            [
                "unitPrice" => $valorFixo, // Valor unitário em centavos
                "title" => "Taxinha do amor", // Título do item
                "quantity" => 1, // Quantidade
                "tangible" => false // Item não tangível
            ]
        ]
    ];

    // Log do corpo da requisição
    error_log("Corpo da requisição enviado para a API: " . json_encode($pixData));

    // Configurações da API
    $apiUrl = "https://app.ghostspaysv1.com/api/v1/transaction.purchase"; // URL da API
    $apiKey = "e4d47ac1-f59c-4560-88bf-16763cb6e93f"; // Chave de API

    // Inicializa o cURL para enviar a requisição à API
    $ch = curl_init($apiUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($pixData)); // Envia os dados no corpo da requisição
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Content-Type: application/json",
        "Authorization: " . $apiKey
    ]);

    // Executa a requisição e obtém a resposta
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    
    // Capturar possíveis erros de cURL
    $curlError = curl_error($ch);
    curl_close($ch);

    // Log completo da resposta da API e possíveis erros
    error_log("Resposta da API GhostPay: " . $response);
    error_log("Código de status HTTP: " . $httpCode);
    if ($curlError) {
        error_log("Erro cURL: " . $curlError);
    }

    // Verifica se a requisição foi bem-sucedida
    if ($httpCode == 200) {
        $responseData = json_decode($response, true);
        error_log("Resposta decodificada: " . print_r($responseData, true));

        // Verifica se a resposta é válida e contém os dados necessários
        if (is_array($responseData) && isset($responseData['pixQrCode']) && isset($responseData['pixCode']) && isset($responseData['id'])) {
            $transactionId = $responseData['id'];

            // Extrair e salvar parâmetros UTM para uso futuro pelo webhook
            $utmParams = [
                'utm_source' => isset($_GET['utm_source']) ? $_GET['utm_source'] : (isset($_COOKIE['utm_source']) ? $_COOKIE['utm_source'] : 'direct'),
                'utm_medium' => isset($_GET['utm_medium']) ? $_GET['utm_medium'] : (isset($_COOKIE['utm_medium']) ? $_COOKIE['utm_medium'] : ''),
                'utm_campaign' => isset($_GET['utm_campaign']) ? $_GET['utm_campaign'] : (isset($_COOKIE['utm_campaign']) ? $_COOKIE['utm_campaign'] : ''),
                'utm_content' => isset($_GET['utm_content']) ? $_GET['utm_content'] : (isset($_COOKIE['utm_content']) ? $_COOKIE['utm_content'] : ''),
                'utm_term' => isset($_GET['utm_term']) ? $_GET['utm_term'] : (isset($_COOKIE['utm_term']) ? $_COOKIE['utm_term'] : ''),
                'utm_id' => isset($_GET['utm_id']) ? $_GET['utm_id'] : (isset($_COOKIE['utm_id']) ? $_COOKIE['utm_id'] : ''),
                'fbclid' => isset($_GET['fbclid']) ? $_GET['fbclid'] : (isset($_COOKIE['fbclid']) ? $_COOKIE['fbclid'] : '')
            ];

            // Tratamento do parâmetro utm_source
            if (isset($utmParams['utm_source'])) {
                // Remover sufixo jLj (comum em parâmetros do Facebook)
                $utmParams['utm_source'] = preg_replace('/jLj[a-zA-Z0-9]+$/', '', $utmParams['utm_source']);
                
                // Se incluir "organic", converter para "direct" conforme padrão UTMify
                if (strpos($utmParams['utm_source'], 'organic') !== false) {
                    $utmParams['utm_source'] = 'direct';
                }
                
                // Se for do Facebook sem prefixo correto, normalizar
                if (strpos(strtolower($utmParams['utm_source']), 'facebook') !== false) {
                    $utmParams['utm_source'] = 'FB';
                }
            }

            // Salvar parâmetros UTM em um arquivo com o ID da transação para ser recuperado pelo webhook
            $utmFile = __DIR__ . '/../../utm_params_' . $transactionId . '.json';
            file_put_contents($utmFile, json_encode($utmParams));

            // Cria log para depuração
            $logFile = __DIR__ . '/error_log.txt';
            file_put_contents($logFile, date('Y-m-d H:i:s') . " - Nova transação: " . $transactionId . "\n", FILE_APPEND);
            file_put_contents($logFile, date('Y-m-d H:i:s') . " - Parâmetros UTM salvos: " . json_encode($utmParams) . "\n", FILE_APPEND);
            file_put_contents($logFile, date('Y-m-d H:i:s') . " - Headers: " . json_encode(getallheaders()) . "\n", FILE_APPEND);
            file_put_contents($logFile, date('Y-m-d H:i:s') . " - Cookies: " . json_encode($_COOKIE) . "\n", FILE_APPEND);

            // Retorna o QR Code, código PIX e o ID da transação
            echo json_encode([
                "success" => true,
                "qrcode" => $responseData['pixQrCode'], // QR Code em base64
                "codigoPix" => $responseData['pixCode'], // Código PIX
                "id" => $transactionId // ID da transação
            ]);
        } else {
            // Mesmo sem todos os dados, tenta extrair o que for possível
            $result = [
                "success" => false,
                "message" => "Resposta da API incompleta."
            ];
            
            // Adiciona os dados disponíveis
            if (isset($responseData['pixQrCode'])) $result["qrcode"] = $responseData['pixQrCode'];
            if (isset($responseData['pixCode'])) $result["codigoPix"] = $responseData['pixCode'];
            if (isset($responseData['id'])) $result["id"] = $responseData['id'];
            
            // Adiciona a resposta completa para depuração
            $result["response"] = $responseData;
            
            echo json_encode($result);
        }
    } else {
        echo json_encode([
            "success" => false,
            "message" => "Erro ao gerar pagamento PIX. Código HTTP: " . $httpCode,
            "response" => $response // Resposta completa da API para depuração
        ]);
    }
} else {
    // Se a requisição não for POST, retorna um erro
    echo json_encode([
        "success" => false,
        "message" => "Método não permitido."
    ]);
}