<?php
// Permitir requisições de qualquer origem
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, Authorization");

// Responder para requisições OPTIONS
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    header("HTTP/1.1 200 OK");
    exit();
}

// Função para salvar logs de forma formatada
function salvarLog($arquivo, $dados, $tipo = 'INFO') {
    // Lista de logs essenciais que serão mantidos
    $logsEssenciais = [
        'webhook.log',         // Log principal
        'erro.log',            // Erros importantes
        'webhook_essencial.log' // Um único log simplificado
    ];
    
    // Verificar se o arquivo está na lista de logs essenciais ou se é um arquivo .json
    $extensao = pathinfo($arquivo, PATHINFO_EXTENSION);
    if (!in_array($arquivo, $logsEssenciais) && $extensao !== 'json') {
        return; // Não salvar logs não essenciais
    }
    
    $timestamp = date('Y-m-d H:i:s');
    $logEntry = [
        'timestamp' => $timestamp,
        'tipo' => $tipo,
        'dados' => $dados
    ];
    file_put_contents($arquivo, json_encode($logEntry, JSON_PRETTY_PRINT) . PHP_EOL, FILE_APPEND);
}

// Função para salvar o status do pagamento
function salvarStatusPagamento($customId, $status) {
    $statusFile = "status_pagamento_$customId.txt";
    file_put_contents($statusFile, $status);
}

// Função para obter o status do pagamento
function obterStatusPagamento($customId) {
    $statusFile = "status_pagamento_$customId.txt";
    if (file_exists($statusFile)) {
        return file_get_contents($statusFile);
    }
    return 'PENDING'; // Status padrão se o arquivo não existir
}

// Verificar se é uma requisição para obter o status do pagamento
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['customId'])) {
    $customId = $_GET['customId'];
    $status = obterStatusPagamento($customId);
    echo json_encode(['status' => $status]);
    exit();
}

// Ler os dados recebidos do webhook
$webhook_content = file_get_contents('php://input');
$dadosWebhook = json_decode($webhook_content, true);

// Salvar log principal só com dados essenciais
salvarLog('webhook.log', $dadosWebhook, 'WEBHOOK');

// Verificar se os dados foram recebidos corretamente
if (empty($dadosWebhook)) {
    salvarLog('erro.log', 'Nenhum dado recebido do webhook. Input bruto: ' . $webhook_content, 'ERRO');
    
    // Mesmo sem dados, vamos tentar processar se tivermos customId na URL
    if (isset($_GET['customId']) || isset($_GET['id'])) {
        $customId = $_GET['customId'] ?? $_GET['id'] ?? '';
        salvarLog('webhook_essencial.log', 'Tentando processar via parâmetros GET com ID: ' . $customId, 'RECOVERY');
        
        // Continuar processamento com dados mínimos
        $dadosWebhook = [
            'status' => 'APPROVED',
            'id' => $customId,
            'customId' => $customId,
            'totalValue' => 5867,
            'netValue' => 5867,
            'createdAt' => date('Y-m-d H:i:s'),
            'approvedAt' => date('Y-m-d H:i:s'),
            'customer' => [
                'name' => 'Cliente',
                'email' => 'cliente@exemplo.com',
                'phone' => '',
                'cpf' => ''
            ]
        ];
    } else {
        // Responder com erro apenas se não tivermos nem dados de webhook nem customId
        die('Erro: Nenhum dado recebido do webhook.');
    }
}

// Mapear o status corretamente para diferentes formatos possíveis
$statusGhostpay = isset($dadosWebhook['status']) ? 
    (is_string($dadosWebhook['status']) ? strtoupper($dadosWebhook['status']) : $dadosWebhook['status']) : '';

$isApproved = $statusGhostpay === 'APPROVED' || 
              $statusGhostpay === 'PAID' || 
              $statusGhostpay === 'COMPLETE' || 
              $statusGhostpay === 'COMPLETED' ||
              $statusGhostpay === 1 || 
              $statusGhostpay === true;

// Definir o status da UTMify com base no status da GhostPay
$statusUtmify = $isApproved ? 'paid' : 'waiting_payment';

// Log simplificado da análise de status
salvarLog('webhook_essencial.log', [
    'status_original' => $dadosWebhook['status'] ?? 'NULL',
    'status_normalizado' => $statusGhostpay,
    'is_approved' => $isApproved ? 'SIM' : 'NÃO',
    'status_utmify' => $statusUtmify
], 'STATUS');

// Salvar o status atual
if (isset($dadosWebhook['customId'])) {
    $customId = $dadosWebhook['customId'];
    $oldStatus = obterStatusPagamento($customId);
    salvarStatusPagamento($customId, $statusGhostpay);
    
    // Verificar se é uma mudança de status para aprovado
    if ($oldStatus !== 'APPROVED' && $isApproved) {
        salvarLog('webhook_essencial.log', [
            'customId' => $customId,
            'status_antigo' => $oldStatus,
            'status_novo' => $statusGhostpay
        ], 'PAGAMENTO_APROVADO');
    }
}

// Extrair os dados relevantes para o log simplificado
$logSimplificado = [
    'id' => $dadosWebhook['customId'] ?? ($dadosWebhook['id'] ?? 'N/A'),
    'nome' => $dadosWebhook['customer']['name'] ?? 'N/A',
    'valor' => $dadosWebhook['totalValue'] ?? 'N/A',
    'status' => $statusGhostpay
];

// Salvar o log simplificado
salvarLog('webhook_essencial.log', $logSimplificado, 'TRANSACAO');

// Salvar o status do pagamento
if (isset($dadosWebhook['status']) && isset($dadosWebhook['customId'])) {
    salvarStatusPagamento($dadosWebhook['customId'], $dadosWebhook['status']);
}

// Salvar uma cópia do webhook recebido (para possível reprocessamento)
if (isset($dadosWebhook['customId'])) {
    $webhookFile = "webhook_" . $dadosWebhook['customId'] . ".json";
    file_put_contents($webhookFile, json_encode($dadosWebhook, JSON_PRETTY_PRINT));
}

// Tentar carregar os parâmetros UTM do arquivo
$utmParams = [
    'utm_source' => '',
    'utm_campaign' => '',
    'utm_medium' => '',
    'utm_content' => '',
    'utm_term' => '',
    'utm_id' => '',
    'fbclid' => ''
];

// Arquivo de parâmetros UTM baseado no ID do pedido
$customId = isset($dadosWebhook['customId']) ? $dadosWebhook['customId'] : '';
$idTransacao = isset($dadosWebhook['id']) ? $dadosWebhook['id'] : '';

// Tentar encontrar o arquivo de parâmetros UTM em várias localizações possíveis
$possiveisArquivosUtm = [
    "utm_params_$customId.json",
    "utm_params_$idTransacao.json",
    __DIR__ . "/utm_params_$customId.json",
    __DIR__ . "/utm_params_$idTransacao.json",
    __DIR__ . "/confirmacao/pagamento/utm_params_$customId.json",
    __DIR__ . "/confirmacao/pagamento/utm_params_$idTransacao.json"
];

// Adicionar busca por qualquer arquivo utm_params que existe no diretório atual
$arquivosUtmGlob = glob('utm_params_*.json');
$possiveisArquivosUtm = array_merge($possiveisArquivosUtm, $arquivosUtmGlob);

// Adicionar busca no diretório de confirmação de pagamento
$arquivosUtmGlobConfirmacao = glob(__DIR__ . '/confirmacao/pagamento/utm_params_*.json');
$possiveisArquivosUtm = array_merge($possiveisArquivosUtm, $arquivosUtmGlobConfirmacao);

$utmArquivoEncontrado = null;
$arquivosMaisRecentes = [];

// Primeiro, encontrar todos os arquivos que existem
$arquivosExistentes = [];
foreach ($possiveisArquivosUtm as $utmFile) {
    if (file_exists($utmFile)) {
        $arquivosExistentes[] = [
            'arquivo' => $utmFile,
            'modificado' => filemtime($utmFile)
        ];
    }
}

// Ordenar arquivos pelo mais recente (maior timestamp de modificação)
usort($arquivosExistentes, function($a, $b) {
    return $b['modificado'] - $a['modificado'];
});

// Pegar o arquivo mais recente, se existir
if (!empty($arquivosExistentes)) {
    $utmArquivoEncontrado = $arquivosExistentes[0]['arquivo'];
    
    // Guarda os 3 arquivos mais recentes para log
    $arquivosMaisRecentes = array_slice($arquivosExistentes, 0, 3);
}

// Tenta carregar os parâmetros UTM do arquivo
if ($utmArquivoEncontrado) {
    $utmFileContent = file_get_contents($utmArquivoEncontrado);
    $utmParamsFromFile = json_decode($utmFileContent, true);
    
    if (is_array($utmParamsFromFile)) {
        // Usar os parâmetros UTM do arquivo
        $utmParams = array_merge($utmParams, $utmParamsFromFile);
        salvarLog('webhook_essencial.log', [
            'arquivo_utm' => basename($utmArquivoEncontrado),
            'utm_source' => $utmParams['utm_source'] ?? '',
            'utm_campaign' => $utmParams['utm_campaign'] ?? '',
            'customId' => $customId
        ], 'UTM_CARREGADO');
    } else {
        salvarLog('erro.log', "Erro ao decodificar parâmetros UTM do arquivo $utmArquivoEncontrado", 'ERRO');
    }
} else {
    // Se não encontrou o arquivo, tentar extrair da URL de confirmação
    $confirmationUrl = $dadosWebhook['confirmationUrl'] ?? '';
    $queryString = parse_url($confirmationUrl, PHP_URL_QUERY);
    parse_str($queryString, $queryParams);
    
    // Extrair parâmetros UTM da URL
    foreach ($utmParams as $key => $value) {
        if (isset($queryParams[$key])) {
            $utmParams[$key] = $queryParams[$key];
        }
    }
    
    salvarLog('webhook_essencial.log', [
        'mensagem' => "UTM da URL",
        'utm_source' => $utmParams['utm_source'] ?? '',
        'utm_campaign' => $utmParams['utm_campaign'] ?? '',
        'customId' => $customId
    ], 'UTM_TRACKING');
}

// Fazer o mapeamento correto para src e sck (obrigatório para UTMify)
// Se utm_source for vazio ou null, usar 'direct'
if (empty($utmParams['utm_source'])) {
    $utmParams['utm_source'] = 'direct';
}

// Gerar identificador único para sck se utm_id estiver vazio
if (empty($utmParams['utm_id']) && (!empty($utmParams['utm_campaign']) || !empty($utmParams['utm_content']))) {
    // Se o utm_id estiver vazio, vamos criar um hash baseado na campanha
    if (!empty($utmParams['utm_campaign'])) {
        $utmParams['utm_id'] = md5($utmParams['utm_campaign'] . $utmParams['utm_source']);
        salvarLog('webhook_essencial.log', [
            'customId' => $customId,
            'utm_id_gerado' => $utmParams['utm_id']
        ], 'UTM_ID_GERADO');
    } elseif (!empty($utmParams['utm_content'])) {
        // Fallback para utm_content se não tivermos utm_campaign
        $utmParams['utm_id'] = md5($utmParams['utm_content'] . $utmParams['utm_source']);
        salvarLog('webhook_essencial.log', [
            'customId' => $customId,
            'utm_id_gerado' => $utmParams['utm_id']
        ], 'UTM_ID_GERADO');
    }
}

// Log dos parâmetros UTM finais
salvarLog('webhook_essencial.log', [
    'utm_source' => $utmParams['utm_source'],
    'utm_campaign' => $utmParams['utm_campaign'],
    'utm_id' => $utmParams['utm_id'],
    'customId' => $customId
], 'UTM_FINAL');

// Montar os dados para a UTMify (completos)
$dadosUtmify = [
    'orderId' => $dadosWebhook['customId'] ?? $dadosWebhook['id'] ?? '',
    'platform' => 'GhostPay',
    'paymentMethod' => 'pix',
    'status' => $statusUtmify,
    'createdAt' => $dadosWebhook['createdAt'] ?? date('Y-m-d H:i:s'),
    'approvedDate' => ($statusUtmify === 'paid') ? ($dadosWebhook['approvedAt'] ?? date('Y-m-d H:i:s')) : null,
    'totalInCents' => $dadosWebhook['totalValue'] ?? 5867, // Campo crítico para tracking
    'refundedAt' => null,
    'customer' => [
        'name' => isset($dadosWebhook['customer']) ? ($dadosWebhook['customer']['name'] ?? '') : '',
        'email' => isset($dadosWebhook['customer']) ? ($dadosWebhook['customer']['email'] ?? '') : '',
        'phone' => isset($dadosWebhook['customer']) ? ($dadosWebhook['customer']['phone'] ?? '') : '',
        'document' => isset($dadosWebhook['customer']) ? ($dadosWebhook['customer']['cpf'] ?? $dadosWebhook['customer']['document'] ?? '') : '',
        'country' => 'BR',
        'ip' => $_SERVER['REMOTE_ADDR'] ?? '127.0.0.1'
    ],
    'products' => [
        [
            'id' => 'taxinha_do_amor',
            'name' => 'Taxinha do amor',
            'planId' => null,
            'planName' => null,
            'quantity' => 1,
            'priceInCents' => $dadosWebhook['totalValue'] ?? 5867
        ]
    ],
    'trackingParameters' => [
        // CRÍTICO: usar utm_source DIRETAMENTE para src e utm_id para sck (ou gerado como fallback)
        'src' => $utmParams['utm_source'],
        'sck' => $utmParams['utm_id'],
        'utm_source' => $utmParams['utm_source'],
        'utm_campaign' => $utmParams['utm_campaign'],
        'utm_medium' => $utmParams['utm_medium'],
        'utm_content' => $utmParams['utm_content'],
        'utm_term' => $utmParams['utm_term'],
        'utm_id' => $utmParams['utm_id'],
        'fbclid' => $utmParams['fbclid']
    ],
    'commission' => [
        'totalPriceInCents' => $dadosWebhook['totalValue'] ?? 5867,
        'gatewayFeeInCents' => isset($dadosWebhook['totalValue']) && isset($dadosWebhook['netValue']) ? 
            ($dadosWebhook['totalValue'] - $dadosWebhook['netValue']) : 0,
        'userCommissionInCents' => $dadosWebhook['netValue'] ?? ($dadosWebhook['totalValue'] ?? 5867)
    ],
    'isTest' => false
];

// Salvar os dados montados para a UTMify no arquivo de log
salvarLog('dados_utmfy.log', $dadosUtmify, 'DADOS_UTMIFY');

// Registrar o status da notificação que será enviada
salvarLog('notificacao_enviada.log', [
    'customId' => $customId,
    'status_ghostpay' => $statusGhostpay,
    'status_utmify' => $statusUtmify,
    'isApproved' => $isApproved ? 'SIM' : 'NÃO',
    'momento' => date('Y-m-d H:i:s')
], 'NOTIFICACAO_ENVIADA');

// Tentar primeiramente a API original que está funcionando
$urlUtmify = 'https://api.utmify.com.br/api-credentials/orders';
$tokenUtmify = 'XRMZ5DcMj6ECZqBD2k34Pke01hnDP9lYpl2x';

$headers = [
    'x-api-token: ' . $tokenUtmify,
    'Content-Type: application/json'
];

$ch = curl_init($urlUtmify);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($dadosUtmify));
curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);

$response = curl_exec($ch);
$httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
$error = curl_error($ch);

curl_close($ch);

// Salvar a resposta da primeira API
salvarLog('utmify_response.log', [
    'api' => 'original',
    'url' => $urlUtmify,
    'httpCode' => $httpCode,
    'response' => $response,
    'error' => $error
], 'RESPOSTA_UTMIFY_ORIGINAL');

// Se falhou, tentar a API alternativa para rastreamento
if ($httpCode < 200 || $httpCode >= 300) {
    // Tentar a API alternativa para rastreamento
    $urlUtmifyAlt = 'https://api.utmify.io/api/orders/create';
    
    $ch = curl_init($urlUtmifyAlt);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($dadosUtmify));
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
    
    $responseAlt = curl_exec($ch);
    $httpCodeAlt = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $errorAlt = curl_error($ch);
    
    curl_close($ch);
    
    // Salvar a resposta da API alternativa
    salvarLog('utmify_response.log', [
        'api' => 'alternativa',
        'url' => $urlUtmifyAlt,
        'httpCode' => $httpCodeAlt,
        'response' => $responseAlt,
        'error' => $errorAlt
    ], 'RESPOSTA_UTMIFY_ALTERNATIVA');
    
    // Se a segunda tentativa teve sucesso, usar esses resultados
    if ($httpCodeAlt >= 200 && $httpCodeAlt < 300) {
        $httpCode = $httpCodeAlt;
        $response = $responseAlt;
    }
}

// Mensagem de sucesso ou erro
if ($httpCode >= 200 && $httpCode < 300) {
    $mensagem = 'Dados enviados para a UTMify com sucesso!';
    salvarLog('webhook_essencial.log', $mensagem, 'SUCESSO');
} else {
    $mensagem = "Erro ao enviar dados para a UTMify. Código HTTP: $httpCode\nResposta: $response";
    salvarLog('webhook_essencial.log', $mensagem, 'ERRO');
}

// Verificar se o pagamento foi aprovado e criar um endpoint para forçar reenvio, se necessário
if (isset($_GET['action']) && $_GET['action'] === 'check_approval' && isset($_GET['id'])) {
    $idToCheck = $_GET['id'];
    $statusToCheck = obterStatusPagamento($idToCheck);
    
    $isApprovedCheck = strtoupper($statusToCheck) === 'APPROVED' || 
                       strtoupper($statusToCheck) === 'PAID' || 
                       strtoupper($statusToCheck) === 'COMPLETE' || 
                       strtoupper($statusToCheck) === 'COMPLETED';
    
    if ($isApprovedCheck) {
        // Se o pagamento está aprovado, tenta recuperar o webhook original
        $webhookFile = "webhook_$idToCheck.json";
        if (file_exists($webhookFile)) {
            $webhookData = json_decode(file_get_contents($webhookFile), true);
            $webhookData['status'] = 'APPROVED'; // Forçar status aprovado
            
            // Simular o processamento do webhook com status aprovado
            $simData = [
                'idToCheck' => $idToCheck,
                'status' => 'APPROVED',
                'message' => 'Envio forçado para UTMify com status APROVADO',
                'timestamp' => date('Y-m-d H:i:s')
            ];
            
            salvarLog('webhook_force.log', $simData, 'ENVIO_FORÇADO');
            
            // Reinvocar o próprio script com os dados corretos
            $ch = curl_init($_SERVER['PHP_SELF']);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($webhookData));
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_exec($ch);
            curl_close($ch);
            
            echo json_encode(['status' => 'success', 'message' => 'Pagamento com status APPROVED foi enviado novamente para UTMify']);
            exit;
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Webhook original não encontrado para reenvio']);
            exit;
        }
    } else {
        echo json_encode(['status' => 'info', 'message' => "Pagamento $idToCheck não está aprovado ainda. Status atual: $statusToCheck"]);
        exit;
    }
}

// Retornar status 200 para o webhook
header('Content-Type: application/json');
http_response_code(200);
echo json_encode(['status' => 'success', 'message' => 'Webhook processado com sucesso']);
exit;